.. module:: bana.OpenMaya.MFnTransform

.. _openmaya_mfntransform:

OpenMaya.MFnTransform
=====================

.. autosummary::
   :nosignatures:

   ~MFnTransform.bnGetScale
   ~MFnTransform.bnSetScale
   ~MFnTransform.bnScaleBy
   ~MFnTransform.bnGetShear
   ~MFnTransform.bnSetShear
   ~MFnTransform.bnShearBy


----

.. automethod:: MFnTransform.bnGetScale

----

.. automethod:: MFnTransform.bnSetScale

----

.. automethod:: MFnTransform.bnScaleBy

----

.. automethod:: MFnTransform.bnGetShear

----

.. automethod:: MFnTransform.bnSetShear

----

.. automethod:: MFnTransform.bnShearBy
